package org.jtheque.core.managers.view;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.Managers;
import org.jtheque.core.managers.view.able.IConfigView;
import org.jtheque.core.managers.view.able.ILicenceView;
import org.jtheque.core.managers.view.able.IMessageView;
import org.jtheque.core.managers.view.able.ILogView;
import org.jtheque.core.managers.view.able.IMainView;
import org.jtheque.core.managers.view.able.components.TabComponent;
import org.jtheque.core.managers.view.able.update.IModuleView;
import org.jtheque.core.managers.view.able.update.IRepositoryView;
import org.jtheque.core.managers.view.able.update.IUpdateView;
import org.jtheque.core.managers.view.edt.SimpleTask;

import javax.swing.JComponent;
import javax.annotation.Resource;

/**
 * A window manager implementation.
 *
 * @author Baptiste Wicht
 */
public final class WindowManager implements Views {
    @Resource
    private IMainView mainView;

    @Resource
    private ILicenceView licenceView;

    @Resource
    private IConfigView configView;

    @Resource
    private IModuleView moduleView;

    @Resource
    private IUpdateView updateView;

    @Resource
    private IRepositoryView repositoryView;

    @Resource
    private IMessageView messageView;

    @Resource
    private ILogView logView;

    @Override
    public void displayMainView() {
        Managers.getManager(IViewManager.class).execute(new SimpleTask() {
            @Override
            public void run() {
                getMainView().display();
            }
        });
    }

    @Override
    public void setSelectedView(TabComponent component) {
        mainView.setSelectedComponent(component.getComponent());
    }

    @Override
    public TabComponent getSelectedView() {
        TabComponent selected = null;

        JComponent component = mainView.getSelectedComponent();

        for (TabComponent tab : Managers.getManager(IViewManager.class).getTabComponents()) {
            if (tab.getComponent().equals(component)) {
                selected = tab;
                break;
            }
        }

        return selected;
    }

    @Override
    public IMainView getMainView() {
        return mainView;
    }

    @Override
    public ILicenceView getLicenceView() {
        return licenceView;
    }

    @Override
    public IConfigView getConfigView() {
        return configView;
    }

    @Override
    public IModuleView getModuleView() {
        return moduleView;
    }

    @Override
    public ILogView getLogView() {
        return logView;
    }

    @Override
    public IUpdateView getUpdateView() {
        return updateView;
    }

    @Override
    public IRepositoryView getRepositoryView() {
        return repositoryView;
    }

    @Override
    public IMessageView getMessagesView() {
        return messageView;
    }
}