package org.jtheque.core.managers.view.impl.components.panel;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jtheque.core.managers.Managers;
import org.jtheque.core.utils.ui.PanelBuilder;
import org.jtheque.core.managers.language.ILanguageManager;
import org.jtheque.core.managers.module.IModuleManager;
import org.jtheque.core.managers.update.repository.ModuleDescription;
import org.jtheque.core.managers.update.versions.VersionsFile;
import org.jtheque.core.managers.update.versions.VersionsFileReader;

import javax.swing.JLabel;
import javax.swing.JPanel;

/**
 * A panel to display the versions of a module.
 *
 * @author Baptiste Wicht
 */
public final class ModuleVersionsPanel extends JPanel {
    private static final long serialVersionUID = -8627886340790323094L;

    private final ModuleDescription description;

    private JLabel onlineLabel;
    private JLabel currentLabel;

    private final PanelBuilder builder;

    /**
     * Construct a new ModuleVersionsPanel.
     *
     * @param description The description of the module.
     */
    public ModuleVersionsPanel(ModuleDescription description) {
        super();

        this.description = description;

        builder = new PanelBuilder(this);

        build();
    }

    /**
     * Build the panel.
     */
    private void build() {
        builder.addLabel("...", builder.gbcSet(0, 0));
        builder.addLabel("...", builder.gbcSet(0, 1));

        onlineLabel = new JLabel();
        currentLabel = new JLabel();
    }

    /**
     * Expand the version.
     */
    public void expand() {
        VersionsFile file = new VersionsFileReader().read(description.getVersionsFileURL());

        onlineLabel.setText(Managers.getManager(ILanguageManager.class).getMessage(
                "repository.module.online",
                file.getMostRecentVersion().getStringVersion()));

        if (Managers.getManager(IModuleManager.class).isInstalled(description.getName())) {
            currentLabel.setText(Managers.getManager(ILanguageManager.class).getMessage(
                    "repository.module.current",
                    Managers.getManager(IModuleManager.class).getModule(description.getName()).getInfos().version()));
        } else {
            currentLabel.setText(Managers.getManager(ILanguageManager.class).getMessage("repository.module.current.notinstalled"));
        }

        removeAll();

        builder.add(onlineLabel, builder.gbcSet(0, 0));
        builder.add(currentLabel, builder.gbcSet(0, 1));
    }
}